==> teapop_0.3.4.orig.tar.gz: teapop-0.3.4/teapop/pop_cmd_capa.c <==
/* $Id: //depot/Teapop/0.3/teapop/pop_cmd_capa.c#3 $ */

/*
 * Copyright (c) 1999-2001 ToonTown Consulting
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the company nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>

#include "config.h"
#include "teapop.h"
#include "pop_cmds.h"
#include "pop_socket.h"
#include "pop_strings.h"
#include "version.h"

void
pop_cmd_capa(arg, pinfo)
	char *arg;
	POP_INFO *pinfo;
{
	if (arg[0] != '\0') {
		pop_socket_send(pinfo->out, "%s %s", POP_ERR, POP_CAPA_BAD);
		return;
	}

	pop_socket_send(pinfo->out, "%s %s", POP_OK, POP_CAPA_OK);
	pop_socket_send(pinfo->out, "TOP");
	pop_socket_send(pinfo->out, "USER");
	pop_socket_send(pinfo->out, "LOGIN-DELAY 900");
	pop_socket_send(pinfo->out, "UIDL");
	pop_socket_send(pinfo->out, "EXPIRE %s",
	    (pinfo->autodelete == 1) ? "0" : "NEVER");
	pop_socket_send(pinfo->out, "IMPLEMENTATION Teapop-v%s", POP_VERSION);
	pop_socket_send(pinfo->out, ".");
}

==> teapop-0.3.5.tar.gz: teapop-0.3.5/teapop/pop_cmd_capa.c <==
/* $Id: //depot/Teapop/0.3/teapop/pop_cmd_capa.c#4 $ */

/*
 * Copyright (c) 1999-2001 ToonTown Consulting
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the company nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>

#include "config.h"
#include "teapop.h"
#include "pop_cmds.h"
#include "pop_socket.h"
#include "pop_strings.h"
#include "version.h"

void
pop_cmd_capa(arg, pinfo)
	char *arg;
	POP_INFO *pinfo;
{
	if (arg[0] != '\0') {
		pop_socket_send(pinfo->out, "%s %s", POP_ERR, POP_CAPA_BAD);
		return;
	}

	pop_socket_send(pinfo->out, "%s %s", POP_OK, POP_CAPA_OK);
	pop_socket_send(pinfo->out, "TOP");
	pop_socket_send(pinfo->out, "USER");
	pop_socket_send(pinfo->out, "LOGIN-DELAY 900");
	pop_socket_send(pinfo->out, "UIDL");
	pop_socket_send(pinfo->out, "EXPIRE %s",
	    (pinfo->autodelete == 1) ? "0" : "NEVER");
	pop_socket_send(pinfo->out, "IMPLEMENTATION Teapop-%s", POP_VERSION);
	pop_socket_send(pinfo->out, ".");
}
